@@ -2,7 +2,7 @@ from functools import wraps
 
 from flask import redirect, session
 
-from ..datas.utils.json import api_return
+from notejob.center.datas.utils.json import api_return
 
 
 def api_err_return(code=1, msg='', data=''):
